@@ -22,6 +22,7 @@
 #include <KConfigGroup>
 #include <KDesktopFile>
 #include <KFileItem>
+#include <KFilePlacesModel>
 #include <KLocalizedString>
 #include <KRun>
 #include <KService>
@@ -32,10 +33,9 @@
 #include <QActionGroup>
 #include <QApplication>
 #include <QJsonArray>
+#include <QScopedPointer>
 #include <QQuickItem>
 #include <QQuickWindow>
-#include <QVersionNumber>
-#include <QTimer>
 
 #include <KActivities/Consumer>
 #include <KActivities/Stats/Cleaning>
@@ -174,6 +174,67 @@ QVariantList Backend::jumpListActions(const QUrl &launcherUrl, QObject *parent)
     return actions;
 }
 
+QVariantList Backend::placesActions(const QUrl &launcherUrl, bool showAllPlaces, QObject *parent)
+{
+    QVariantList actions;
+
+    if (!parent || !launcherUrl.isValid() || !launcherUrl.isLocalFile()
+        || !KDesktopFile::isDesktopFile(launcherUrl.toLocalFile())) {
+        return actions;
+    }
+
+    KDesktopFile desktopFile(launcherUrl.toLocalFile());
+
+    // Since we can't have dynamic jump list actions, at least add the user's "Places" for file managers.
+    const QStringList &categories = desktopFile.desktopGroup().readXdgListEntry(QStringLiteral("Categories"));
+    if (!categories.contains(QLatin1String("FileManager"))) {
+        return actions;
+    }
+
+    QScopedPointer<KFilePlacesModel> placesModel(new KFilePlacesModel());
+    for (int i = 0; i < placesModel->rowCount(); ++i) {
+        QModelIndex idx = placesModel->index(i, 0);
+
+        if (placesModel->data(idx, KFilePlacesModel::HiddenRole).toBool()) {
+            continue;
+        }
+
+        const QString &title = placesModel->data(idx, Qt::DisplayRole).toString();
+        const QIcon &icon = placesModel->data(idx, Qt::DecorationRole).value<QIcon>();
+        const QUrl &url = placesModel->data(idx, KFilePlacesModel::UrlRole).toUrl();
+
+        QAction *action = new QAction(icon, title, parent);
+
+        connect(action, &QAction::triggered, this, [this, action, url, launcherUrl] {
+            KService::Ptr service = KService::serviceByDesktopPath(launcherUrl.toLocalFile());
+            if (!service) {
+                return;
+            }
+
+            KRun::runService(*service, {url}, QApplication::activeWindow());
+        });
+
+        actions << QVariant::fromValue(action);
+    }
+
+    // There is nothing more frustrating than having a "More" entry that ends up showing just one or two
+    // additional entries. Therefore we truncate to max. 5 entries only if there are more than 7 in total.
+    if (!showAllPlaces && actions.count() > 7) {
+        const int totalActionCount = actions.count();
+
+        while (actions.count() > 5) {
+            actions.removeLast();
+        }
+
+        QAction *action = new QAction(parent);
+        action->setText(i18ncp("Show all user Places", "%1 more Place", "%1 more Places", totalActionCount - actions.count()));
+        connect(action, &QAction::triggered, this, &Backend::showAllPlaces);
+        actions << QVariant::fromValue(action);
+    }
+
+    return actions;
+}
+
 QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *parent)
 {
     QVariantList actions;
@@ -329,29 +390,9 @@ QRect Backend::globalRect(QQuickItem *item) const
 
 void Backend::ungrabMouse(QQuickItem *item) const
 {
-    //this is a workaround where Qt will fail to realise a mouse has been released
-
-    // this happens if a window which does not accept focus spawns a new window that takes focus and X grab
-    // whilst the mouse is depressed
-    // https://bugreports.qt.io/browse/QTBUG-59044
-    // this causes the next click to go missing
-
-    //by releasing manually we avoid that situation
-    auto ungrabMouseHack = [item]() {
-        if (item && item->window() &&  item->window()->mouseGrabberItem()) {
-            item->window()->mouseGrabberItem()->ungrabMouse();
-        }
-    };
-
-    //pre 5.8.0 QQuickWindow code is "item->grabMouse(); sendEvent(item, mouseEvent)"
-    //post 5.8.0 QQuickWindow code is sendEvent(item, mouseEvent); item->grabMouse()
-    if (QVersionNumber::fromString(qVersion()) > QVersionNumber(5, 8, 0)) {
-        QTimer::singleShot(0, item, ungrabMouseHack);
+    if (item && item->window() &&  item->window()->mouseGrabberItem()) {
+        item->window()->mouseGrabberItem()->ungrabMouse();
     }
-    else {
-        ungrabMouseHack();
-    }
-    //end workaround
 }
 
 bool Backend::canPresentWindows() const
